﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;
using System.Speech.Synthesis;

namespace Text2Speech
{
    public partial class Speech : Form
    {
        SpeechSynthesizer mySynth = new SpeechSynthesizer();

        public Speech()
        {
            InitializeComponent();
        }

        private void GetInstalledVoices(System.Speech.Synthesis.SpeechSynthesizer synth)
        {
            ReadOnlyCollection<InstalledVoice> voices = synth.GetInstalledVoices();

            if (voices.Count == 0)
            {
                //no voices installed, so disable controls
                SpeakButton.Enabled = false;
                volumeTrackBar.Enabled = false;
                speedTrackBar.Enabled = false;
            }
            else
            {
                try
                {
                    VoiceInfo voiceInformation = voices[0].VoiceInfo;

                    foreach (InstalledVoice v in voices)
                    {
                        voiceInformation = v.VoiceInfo;
                        ComboBox1.Items.Add(voiceInformation.Name.ToString());
                    }
                }
                catch (Exception ex)
                {
                }
            }
        }

        private void SpeakButton_Click(object sender, EventArgs e)
        {
            if (!String.IsNullOrEmpty(ComboBox1.Text) && !String.IsNullOrEmpty(textBox1.Text))
            {
                mySynth.SelectVoice(ComboBox1.Text);
                mySynth.SpeakAsync(textBox1.Text);

                CancelButton.Enabled = true;
            }
        }

        private void CancelButton_Click(object sender, EventArgs e)
        {
            mySynth.SpeakAsyncCancelAll();
            CancelButton.Enabled = false;
        }

        private void speedTrackBar_ValueChanged(object sender, EventArgs e)
        {
            mySynth.Rate = speedTrackBar.Value;
        }

        private void volumeTrackBar_ValueChanged(object sender, EventArgs e)
        {
            mySynth.Volume = volumeTrackBar.Value;
        }

        private void Speech_Load(object sender, EventArgs e)
        {
            GetInstalledVoices(mySynth);
            SpeakButton_Click(sender, e);
        }

        private void Speech_FormClosing(object sender, FormClosingEventArgs e)
        {
            mySynth.SpeakAsyncCancelAll();
        }
    }
}
