﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;
using System.Speech.Synthesis;
using Microsoft.Office.Interop;
using Text2SpeechAddin;

namespace TextToSpeech
{
    public partial class SpeechControl : UserControl
    {
        SpeechSynthesizer mySynth = new SpeechSynthesizer();

        public SpeechControl()
        {
            InitializeComponent();
        }

        private void GetInstalledVoices(System.Speech.Synthesis.SpeechSynthesizer synth)
        {
            ReadOnlyCollection<InstalledVoice> voices = synth.GetInstalledVoices();

            if (voices.Count == 0)
            {
                //no voices installed, so disable controls
                SpeakButton.Enabled  = false;
                volumeTrackBar.Enabled = false;
                speedTrackBar.Enabled = false;
            }
            else
            {
                try
                {
                    VoiceInfo voiceInformation = voices[0].VoiceInfo;

                    foreach (InstalledVoice v in voices)
                    {
                        voiceInformation = v.VoiceInfo;
                        ComboBox1.Items.Add(voiceInformation.Name.ToString());
                    }
                }
                catch (Exception ex)
                {
                }
            }
        }

        private void SpeakButton_Click(object sender, EventArgs e)
        {
            if(String.IsNullOrEmpty(ComboBox1.Text))
            {
            }
            else
            {
                mySynth.SelectVoice(ComboBox1.Text);

                string text = Globals.ThisAddIn.Application.ActiveDocument.Content.Text;
                mySynth.SpeakAsync(text);

                CancelButton.Enabled = true;
            }
        }

        private void CancelButton_Click(object sender, EventArgs e)
        {
            mySynth.SpeakAsyncCancelAll();
            CancelButton.Enabled = false;
        }

        private void SpeechControl_Load(object sender, EventArgs e)
        {
            GetInstalledVoices(mySynth);
        }

        private void speedTrackBar_ValueChanged(object sender, EventArgs e)
        {
            mySynth.Rate = speedTrackBar.Value;
        }

        private void volumeTrackBar_ValueChanged(object sender, EventArgs e)
        {
            mySynth.Volume = volumeTrackBar.Value;
        }
    }
}
